@@ -27,10 +27,10 @@
 /*
  * This file contains modifications Copyright 2006-2011 J. Schilling
  *
- * @(#)delta.c	1.41 11/08/07 J. Schilling
+ * @(#)delta.c	1.43 11/08/22 J. Schilling
  */
 #if defined(sun)
-#pragma ident "@(#)delta.c 1.41 11/08/07 J. Schilling"
+#pragma ident "@(#)delta.c 1.43 11/08/22 J. Schilling"
 #endif
 /*
  * @(#)delta.c 1.40 06/12/12
@@ -333,9 +333,8 @@ char *file;
 	if (setjmp(Fjmp))
 		return;
 	sinit(&gpkt,file,1);
-	gpkt.p_flags |= PF_GMT;
-	if (getenv("SCCS_VERSION"))
-		gpkt.p_flags |= PF_V6;
+	if ((gpkt.p_flags & PF_V6) == 0)
+		gpkt.p_flags |= PF_GMT;
 	if (first) {
 		first = 0;
 		dohist(file);
@@ -680,8 +679,7 @@ int orig_nlines;
 		fprintf(pkt->p_stdout,"%s\n",str);
 		fflush(pkt->p_stdout);
 	}
-	sprintf(str, NOGETTEXT("%c%c00000\n"), CTLCHAR, HEAD);
-	putline(pkt,str);
+	putmagic(pkt, "00000");
 	newstats(pkt,str,"0");
 	dt.d_sid = *sp;
 
@@ -716,18 +714,20 @@ int orig_nlines;
 		dt.d_pred = newser - 1;	/* set predecessor to 'null' delta */
 	else
 		dt.d_pred = opred;
-	dt.d_datetime = Timenow;
+
+	time2dt(&dt.d_dtime, Timenow, 0); /* Timenow was set by dodelt() */
+
         /* Since the NSE always preserves the clear file after delta and
          * makes it read only (no get is required since keywords are not
          * supported), the delta time is set to be the mtime of the clear
          * file.
          */
         if ((HADO || HADQ) && (gfile_mtime != 0)) {
-                dt.d_datetime = gfile_mtime;
+		time2dt(&dt.d_dtime, gfile_mtime, 0);
         }
 	strncpy(dt.d_pgmr,logname(),LOGSIZE-1);
 	dt.d_type = 'D';
-	del_ba(&dt,str, 0);
+	del_ba(&dt,str, pkt->p_flags & ~PF_GMT);
 	putline(pkt,str);
 	if (ilist)
 		mkixg(pkt,INCLUSER,INCLUDE);
